@@ -52,12 +52,19 @@ class FlaskRedis(object):
 
 
 class SentinelRedisConnector(object):
+    sentinel_option_types = {
+        'min_other_sentinels': int,
+        'socket_timeout': float
+    }
+
+    def __init__(self, sentinel_url, **connection_options):
+        if connection_options is None:
+            connection_options = {}
 
-    def __init__(self, sentinel_url):
         self.sentinel_config = self._parse_url(sentinel_url)
-        options = self.sentinel_config.options
-        if (redis_pattern.match(redis_version)):
-            options = {
+        connection_options.update(self.sentinel_config.options)
+        if redis_pattern.match(redis_version):
+            connection_options = {
                 'password': self.sentinel_config.options.get('password', None),
                 'socket_timeout':
                     self.sentinel_config.options.get('socket_timeout', None),
@@ -65,7 +72,14 @@ class SentinelRedisConnector(object):
                     self.sentinel_config.options.get('min_other_sentinels', 0),
             }
 
-        self.sentinel = Sentinel(self.sentinel_config.hosts, **options)
+        sentinel_kwargs = connection_options.copy()
+        for k in self.sentinel_option_types.keys():
+            if k in sentinel_kwargs:
+                del sentinel_kwargs[k]
+
+        self.sentinel = Sentinel(self.sentinel_config.hosts,
+                                 sentinel_kwargs=sentinel_kwargs,
+                                 **connection_options)
 
     def _parse_url(self, sentinel_url):
         if sentinel_url is None:
@@ -80,10 +94,6 @@ class SentinelRedisConnector(object):
             raise ValueError("Invalid path: {0}. Must be of the form "
                              "/cluster-name/db-number".format(url.path))
 
-        sentinel_option_types = {
-            'min_other_sentinels': int,
-            'socket_timeout': float
-        }
         connection_options = {
             'db': int(path_parts[2])
         }
@@ -100,14 +110,14 @@ class SentinelRedisConnector(object):
         hosts = self._parse_hosts(hostspec)
 
         for name, value in iteritems(urlparse.parse_qs(url.query)):
-            if name not in sentinel_option_types:
+            if name not in self.sentinel_option_types:
                 continue
 
             if len(value) > 1:
                 raise ValueError('Multiple values specified for {}'
                                  .format(name))
 
-            _type = sentinel_option_types[name]
+            _type = self.sentinel_option_types[name]
             connection_options[name] = _type(value[0])
 
         return SentinelConfig(hosts, connection_options, path_parts[1])
